@@ -1,5 +1,5 @@
 package Form::Factory::Test::Action::Basic;
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 
 use Test::Able;
@@ -10,7 +10,7 @@ with qw( Form::Factory::Test::Action );
 
 has '+action' => (
     lazy       => 1,
-    default    => sub { shift->factory->new_action('TestApp::Action::Basic' => {
+    default    => sub { shift->interface->new_action('TestApp::Action::Basic' => {
         value_to_defer => 'Superbark',
     }) },
 );
